@@ -1,7 +1,15 @@
+from django import forms
 from django.contrib import admin
 
 from examples.models import Task, Status, Project, Priority
-from richtemplates.forms import LimitingModelForm
+from richtemplates.forms import RestructuredTextAreaField
+
+
+class TaskFormAdmin(forms.ModelForm):
+    content = RestructuredTextAreaField()
+
+    class Meta:
+        model = Task
 
 class TaskAdmin(admin.ModelAdmin):
     list_displa = ['project', 'summary', 'created_at', 'author', 'edited_at',
@@ -10,13 +18,14 @@ class TaskAdmin(admin.ModelAdmin):
     date_hierarchy = 'created_at'
     save_on_top = True
     search_fields = ['summary', 'content']
+    form = TaskFormAdmin
 
 class StatusInline(admin.StackedInline):
-    model = Status 
+    model = Status
     extra = 1
 
 class PriorityInline(admin.StackedInline):
-    model = Priority 
+    model = Priority
     extra = 1
 
 class ProjectAdmin(admin.ModelAdmin):
@@ -24,7 +33,7 @@ class ProjectAdmin(admin.ModelAdmin):
     save_on_top = True
     search_fields = ['name']
     inlines = [StatusInline, PriorityInline]
-    
+
 admin.site.register(Task, TaskAdmin)
 admin.site.register(Status)
 admin.site.register(Project, ProjectAdmin)
