@@ -52,7 +52,7 @@ def autocomplete_field(bfield, **opts):
 autocomplete_field.function = True
 
 def do_get_code_style(context):
-    user = context['user']
+    user = context.get('user', None)
     if user and user.is_authenticated():
         style = getattr(user.get_profile(),
             richtemplates_settings.PROFILE_CODE_STYLE_FIELD,
@@ -84,6 +84,18 @@ def richicon(icon, **opts):
     return tag
 richicon.function = True
 
+def boolicon(value=None, **opts):
+    """
+    Returns html's ``img`` tag with *yes* icon if value is ``True``,
+    **no** icon otherwise.
+    """
+    if value:
+        icon = 'icon-yes.gif'
+    else:
+        icon = 'icon-no.gif'
+    return richicon(icon, **opts)
+boolicon.function = True
+
 def richuiicon(icon, **opts):
     """
     Returns ``button`` + ``span`` tags representing jQuery ui icon for a given
